% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RcppExports.R
\name{lrsim3a}
\alias{lrsim3a}
\title{Log-rank test simulation for three arms}
\usage{
lrsim3a(
  kMax = NA_integer_,
  hazardRatioH013 = 1,
  hazardRatioH023 = 1,
  hazardRatioH012 = 1,
  allocation1 = 1L,
  allocation2 = 1L,
  allocation3 = 1L,
  accrualTime = 0L,
  accrualIntensity = NA_real_,
  piecewiseSurvivalTime = 0L,
  stratumFraction = 1L,
  lambda1 = NA_real_,
  lambda2 = NA_real_,
  lambda3 = NA_real_,
  gamma1 = 0L,
  gamma2 = 0L,
  gamma3 = 0L,
  accrualDuration = NA_real_,
  followupTime = NA_real_,
  fixedFollowup = 0L,
  rho1 = 0,
  rho2 = 0,
  plannedEvents = NA_integer_,
  plannedTime = NA_real_,
  maxNumberOfIterations = 1000L,
  maxNumberOfRawDatasetsPerStage = 0L,
  seed = NA_integer_
)
}
\arguments{
\item{kMax}{The maximum number of stages.}

\item{hazardRatioH013}{Hazard ratio under the null hypothesis for arm 1
versus arm 3. Defaults to 1 for superiority test.}

\item{hazardRatioH023}{Hazard ratio under the null hypothesis for arm 2
versus arm 3. Defaults to 1 for superiority test.}

\item{hazardRatioH012}{Hazard ratio under the null hypothesis for arm 1
versus arm 2. Defaults to 1 for superiority test.}

\item{allocation1}{Number of subjects in Arm A in
a randomization block. Defaults to 1 for equal randomization.}

\item{allocation2}{Number of subjects in Arm B in
a randomization block. Defaults to 1 for equal randomization.}

\item{allocation3}{Number of subjects in Arm C in
a randomization block. Defaults to 1 for equal randomization.}

\item{accrualTime}{Accrual time intervals, must start with 0, e.g.,
\code{c(0, 3)} breaks the time axis into 2 accrual intervals:
[0, 3) and [3, Inf).}

\item{accrualIntensity}{A vector of accrual intensities, one for
each accrual time interval.}

\item{piecewiseSurvivalTime}{A vector that specifies the time intervals for
the piecewise exponential survival distribution, must start with 0, e.g.,
\code{c(0, 6)} breaks the time axis into 2 event intervals:
[0, 6) and [6, Inf).
Defaults to 0 for exponential distribution.}

\item{stratumFraction}{A vector of stratum fractions that sum to 1.
Defaults to 1 for no stratification.}

\item{lambda1}{A vector of hazard rates for the event in each analysis
time interval by stratum for arm 1.}

\item{lambda2}{A vector of hazard rates for the event in each analysis
time interval by stratum for arm 2.}

\item{lambda3}{A vector of hazard rates for the event in each analysis
time interval by stratum for arm 3.}

\item{gamma1}{The hazard rate for exponential dropout, a vector of 
hazard rates for piecewise exponential dropout applicable for all 
strata, or a vector of hazard rates for dropout in each analysis time 
interval by stratum for arm 1.}

\item{gamma2}{The hazard rate for exponential dropout, a vector of 
hazard rates for piecewise exponential dropout applicable for all 
strata, or a vector of hazard rates for dropout in each analysis time 
interval by stratum for arm 2.}

\item{gamma3}{The hazard rate for exponential dropout, a vector of 
hazard rates for piecewise exponential dropout applicable for all 
strata, or a vector of hazard rates for dropout in each analysis time 
interval by stratum for arm 3.}

\item{accrualDuration}{Duration of the enrollment period.}

\item{followupTime}{Follow-up time for the last enrolled subject.}

\item{fixedFollowup}{Whether a fixed follow-up design is used.
Defaults to 0 for variable follow-up.}

\item{rho1}{First parameter of the Fleming-Harrington family of weighted
log-rank test. Defaults to 0 for conventional log-rank test.}

\item{rho2}{Second parameter of the Fleming-Harrington family of weighted
log-rank test. Defaults to 0 for conventional log-rank test.}

\item{plannedEvents}{The planned cumulative total number of events at 
Look 1 to Look \code{kMax} for Arms A and C combined.}

\item{plannedTime}{The planned analysis time for each stage needed for
analyses planned at calendar times, in which case, \code{plannedEvents} 
should be missing.}

\item{maxNumberOfIterations}{The number of simulation iterations.
Defaults to 1000.}

\item{maxNumberOfRawDatasetsPerStage}{The number of raw datasets per stage
to extract. Defaults to 1.}

\item{seed}{The seed to reproduce the simulation results.
The computer clock will be used if left unspecified,}
}
\value{
A list with 2 components:

* \code{sumdata} is a data frame of summary data by stage for each
iteration, containing the analysis time, number of accrued subjects 
overall and by treatment group, and number of events overall and 
by treatment group, number of dropouts overall and by treatment group, 
and log-rank test statistic for each comparison.

* \code{rawdata} (exists if \code{maxNumberOfRawDatasetsPerStage} is a
positive integer) is a data frame for subject-level data for selected
replications, containing the stage number, subject number, arrival time, 
stratum, treatment group, observation time, and survival time, 
dropout time, time under observation, event and dropout indicators.
}
\description{
Performs simulation for three-arm group 
sequential trials based on weighted log-rank test. The  
looks are driven by the total number of events in Arm A 
and Arm C combined.
}
\examples{

sim1 = lrsim3a(
  kMax = 3, 
  allocation1 = 2, 
  allocation2 = 2, 
  allocation3 = 1,
  accrualTime = c(0, 8), 
  accrualIntensity = c(10, 28),
  piecewiseSurvivalTime = 0, 
  lambda1 = log(2)/12*0.60,
  lambda2 = log(2)/12*0.70,
  lambda3 = log(2)/12,
  accrualDuration = 30.143,
  plannedEvents = c(186, 259, 295),
  maxNumberOfIterations = 1000,
  maxNumberOfRawDatasetsPerStage = 1,
  seed = 314159)
  
head(sim1$sumdata)
head(sim1$rawdata)

}
